Skip site navigation (1)Skip section navigation (2)
Date:      Tue, 18 Dec 2001 21:07:42 -0500 (EST)
From:      Mike Buchanon <buchanon@mlss15.cl.msu.edu>
To:        FreeBSD-gnats-submit@freebsd.org
Subject:   ports/32996: bcpp port upgrade
Message-ID:  <200112190207.fBJ27gRA050990@manetheren.cl.msu.edu>

next in thread | raw e-mail | index | archive | help

>Number:         32996
>Category:       ports
>Synopsis:       bcpp port upgrade
>Confidential:   no
>Severity:       non-critical
>Priority:       medium
>Responsible:    freebsd-ports
>State:          open
>Quarter:        
>Keywords:       
>Date-Required:
>Class:          update
>Submitter-Id:   current-users
>Arrival-Date:   Tue Dec 18 18:10:00 PST 2001
>Closed-Date:
>Last-Modified:
>Originator:     Mike Buchanon
>Release:        FreeBSD 4.4-STABLE i386
>Organization:
>Environment:
System: FreeBSD manetheren.cl.msu.edu 4.4-STABLE FreeBSD 4.4-STABLE #14: Mon Oct 8 11:05:55 EDT 2001 root@manetheren.cl.msu.edu:/usr/obj/usr/src/sys/MANETHEREN i386


>Description:
	PORT UPGRADE of devel/bcpp to honor prefix and fix warnings
>How-To-Repeat:
	make install
>Fix:

	Apply patch:

diff -urN /usr/ports/devel/bcpp/Makefile bcpp/Makefile
--- /usr/ports/devel/bcpp/Makefile	Sat Nov 17 22:33:44 2001
+++ bcpp/Makefile	Tue Dec 18 20:03:13 2001
@@ -18,10 +18,14 @@
 MAKEFILE=	makefile
 ALL_TARGET=	${PORTNAME}
 
+post-patch:
+	@${PERL5} -pi -e 's,%%PREFIX%%,${PREFIX},g' ${WRKSRC}/bcpp.cpp
+
 do-install:
 	${INSTALL_PROGRAM} ${WRKSRC}/${PORTNAME} ${PREFIX}/bin
 	${INSTALL_DATA} ${WRKSRC}/${PORTNAME}.cfg \
 		${PREFIX}/etc/${PORTNAME}.cfg.sample
+
 .if !defined(NOPORTDOCS)
 	${MKDIR} ${DOCSDIR}
 	${INSTALL_MAN} ${WRKDIR}/${DISTNAME}/txtdocs/hirachy.txt ${DOCSDIR}
diff -urN /usr/ports/devel/bcpp/pkg-message bcpp/pkg-message
--- /usr/ports/devel/bcpp/pkg-message	Sat Nov 17 22:33:44 2001
+++ bcpp/pkg-message	Tue Dec 18 20:30:22 2001
@@ -1,2 +1,2 @@
-You should modify /usr/local/etc/bcpp.cfg to your liking and 
+You should modify /usr/local/etc/bcpp.cfg.sample to your liking and 
 copy it to /usr/local/etc/bcpp.cfg
>Release-Note:
>Audit-Trail:
>Unformatted:

To Unsubscribe: send mail to majordomo@FreeBSD.org
with "unsubscribe freebsd-ports" in the body of the message




Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?200112190207.fBJ27gRA050990>
diff -urN /usr/ports/devel/bcpp/files/patch-bcpp.cpp bcpp/files/patch-bcpp.cpp
--- /usr/ports/devel/bcpp/files/patch-bcpp.cpp	Sat Nov 17 22:33:45 2001
+++ bcpp/files/patch-bcpp.cpp	Tue Dec 18 20:32:46 2001
@@ -1,20 +1,36 @@
 --- bcpp.cpp.orig	Tue Aug 10 20:54:52 1999
-+++ bcpp.cpp	Wed Nov  7 10:48:27 2001
-@@ -2721,6 +2721,7 @@
++++ bcpp.cpp	Tue Dec 18 20:22:18 2001
+@@ -1431,6 +1431,7 @@
+ 
+ }
+ 
++/*
+ // purge an Indent-stack
+ static void freeIndentStack(StackList* pImode)
+ {
+@@ -1451,6 +1452,7 @@
+         dst -> push(temp);
+     }
+ }
++*/
+ 
+ // no extra indent immediately after any brace
+ void resetSingleIndent(StackList* pIMode)
+@@ -2721,6 +2723,7 @@
      char* pSPath      = getenv ("PATH");
      char* pEPath      = NULL;
      char* pNameMem    = NULL;
-+    char* tmpCfgName  = new char[ 16 + strlen(pCfgName) + 1];
++    char* tmpCfgName  = new char[strlen("%%PREFIX%%/etc")+strlen(pCfgName)+1];
      char  sepChar     = NULLC;
      const char* pathSepChar;
      char  backUp;
-@@ -2729,6 +2730,13 @@
+@@ -2729,6 +2732,13 @@
      // test to see if file is in current directory first !
      if ((pCfgFile = fopen(pCfgName, "r")) != NULL)
          return;
 +
-+    // look to see if it's in /usr/local/etc
-+    tmpCfgName = strcat( tmpCfgName, "/usr/local/etc/" );
++    // look to see if it's in %%PREFIX%%/etc
++    tmpCfgName = strcat( tmpCfgName, "%%PREFIX%%/etc/" );
 +    tmpCfgName = strcat( tmpCfgName, pCfgName );
 +    if ((pCfgFile = fopen(tmpCfgName, "r")) != NULL)
 +	    return;